PublicKey

Struct PublicKey 

pub struct PublicKey(/* private fields */);
Bytes that are intended/thought to correspond to a point on the Edwards25519 curve (but not on its twist).

This is more compact than VerifyingKey in memory, and easier to handle, but it is not guaranteed to be a valid point on the curve, so cannot be used for actual cryptographic operations such as signature verification or Diffie-Hellman key exchange.

Implementations

Source

impl PublicKey

pub const fn from_bytes(bytes: [u8; 32]) -> PublicKey

pub fn into_inner(self) -> [u8; 32]

Source

impl PublicKey

pub fn to_human(&self) -> String

Encode public key in human-readable format.

MULTIBASE(base58-btc, MULTICODEC(public-key-type, raw-public-key-bytes))

pub fn to_namespace(&self) -> RefString

Encode the public key to a Git reference string:

refs/namespaces/<public-key>

and <public-key> is encoded in human-readable format (PublicKey::to_human).

pub fn to_component(&self) -> Component<'_>

Encode the public key a Git reference component, which is equivalent to the human-readable format (PublicKey::to_human).

pub fn from_namespaced( refstr: &Namespaced<'_>, ) -> Result<PublicKey, PublicKeyError>

Decode a PublicKey from a namespaced Git reference, expected to be in the format:

refs/namespaces/<public-key>/…

The <public-key> is decoded from the human-readable format (PublicKey::to_human).